@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "keychain-environment" "2.4.1"
+(define-package "keychain-environment" "20251123.46"
   "Load keychain environment variables."
   ()
   :url "https://github.com/tarsius/keychain-environment"
-  :commit "d3643196de6dc79ea77f9f4805028350fd76100b"
-  :revdesc "2.4.1-0-gd3643196de6d"
+  :commit "d2fa34404fe3a58bd7e708e73b77be43f46eb4cc"
+  :revdesc "d2fa34404fe3"
   :keywords '("gnupg" "pgp" "ssh")
   :authors '(("Paul Tipper" . "bluefooatgooglemaildotcom"))
   :maintainers '(("Jonas Bernoulli" . "jonas@bernoul.li")))
